/*Pulse Sequence Code for real-time pure shift gHSQC in proteins using 15N-BIRD vs. NH-sel vs 13C-BIRD*/
/*---------------------------------------------------------------------------------------------------------------------------
Developed By NMR Group
School of Chemistry
University of Manchester
United Kingdom
Oct 2013

------------------------------------------------------------------------
User's Guide for experimental setup:
------------------------------------------------------------------------
1. BIRD = 'n' selects conventional gHSQC
-----------------------------------------------------------------------
2.  BIRD = 'y' selects real-time pure shift gHSQC (gHSQC-BIRD)
    	Four options within BIRD are:
		BIRDmode ='h' selects hard 13C inversion pulse during BIRD // large off-resonance effect, not recommended 
		BIRDmode ='b' selects BIP 13C inversion pulse during BIRD
			(parameters to adjust: shp_HBIP, pw_HBIP, pwr_HBIP and shp_XBIP, pw_XBIP and pwr_XBIP)		
		BIRDmode ='w' selects a pair of wurst adiabatic 13C inversion pulses during BIRD
			(parameters to adjust: identical to standards in gHSQCAD)		
		BIRDmode ='n' selects a 1H band-selective inversion pulse instead of BIRD-filter // applyed for NH-region in proteins to reduce relaxation loss in real-time ACQ 
			(parameters to adjust: shp_HBIP, pw_HBIP, pwr_HBIP and shp_XBIP, pw_XBIP and pwr_XBIP)		
		BIRDmode ='Y' selects a 13C-BIRD for CH-band in proteins // applyed for 15N-HSQC in 15N-13C labelled proteins or the oposite with N15-BIRD on the Y-channel and real-time pure shift on X-channel 
			(parameters to adjust: 
				      obs(H1): shp_HBIP, pw_HBIP, pwr_HBIP
				      dec(N15): shp_XBIP, pw_XBIP and pwr_XBIP
				      dec2(C13): shp_YBIP, pw_YBIP and pwr_YBIP)		

		For all np should be integer submultiple of npoints
		Users control chunking time using npoints so that np/npoints is an integer
		Note:
		chunk_time=npoints/(2*sw)=at/cycles  
		cycles=np/npoints, an integer
		at=np/(2*sw)=cycles*npoints/(2*sw)=cycles*chunk_time
--------------------------------------------------------------------------------------------------------------------------------*/

/* pulse-sequence based on LPKP_final_rtgHSQCBIRD_Suppl_NHsel.c published in Angew.Chem.Int.Ed. 2013 (without the NHsel option)

modifications by kp
_01   	added optional band-selective mode for proteins using selfrq
	implement option for 13C-BIRD in the 15-HSQC //under construction!!
_02   	trials for triple-resonance
_03	optional modifed phase-cycle   //bad idea
_04	modifications in BIRDmode='Y' 
_05	CTP during ACQ and lkgate_flg
_06	water flip-back
  _06a-d	CTP variants
_07
_08	CTP and water flip-back implemented
WSUPP does not work
_09  	13C-BIRD and 13C-dec during t1 & t2 
BIRDmode='Y' does not work properly
_10	NHsel modified
_11 	BIRDmode='y' [NHsel-C13BIRD-NHsel] 
_12	CTP for NHsel (gt3 does not work)
_13	yBIRD uses 13C-BIRD (inv.remote protons) + hard180 (water should be uneffected between chunks)
_14	WSUPP was omitted
	d1_corr was fixed
_15	sel90_hard180_sel90 mode was added via BIRDmode='N'
_16t	triax support for CTP during ACQ
_17	timing corrected for NHsel
_18	phase-cycle test option via kpph
	d1_corr fixed for NHsel
_19	clear useless old options
	hsgradaxis supports triax
	d1_corr normalized to bip-BIRD and supports HSQC/bip-BIRD/NHsel 
_20	kpdof and kptof option to observe F1-Aliased 2D but pulse onresonance except in BIRD/NHsel
_21	kp_X180 flag to change X pulses in BIRD (0: std. as before; 1: 2nd X-180 centered on the last proton 90 pulse; 2: 2nd X-180 centered on the hard proton 180)
_21a	fixed the proton hard 180 pulse length and phase; all experiments with kp_X180=2 are bad with _21 
_22	offRes_DEC and offRes_X180 for set offset on HPWR DEC and interchunk pulses on dec (kpdof and kptof are omitted)
_24	calH and calX (cal_pwlvl and cal_pwxlvl) to support calibrations
_25	phase cycle sorted out; kpph controls
_26	correction for calibrations (calH, cal_pwlvl and cal_pw; calX, cal_pwxlvl and cal_pwx)
_27	improvements to avoid timing issue with gt1; new values for kp_X180
_28	skipped (trial with parallel sections)
_29	kp_X180=4 according to Ralph's simulations (correctly programmed as GAM suggested)
_30	normal ACQ is coded with explicit ACQ to avoid any frequency shift between pure-shift and parent experiments
_31	try to perform HDEC
*/


#include <standard.h>
//#include <chempack.h>

/*------------------------------------------
Phase tables for Varian gHSQC
--------------------------------------------*/

static int	 ph1[4]  = {1,1,3,3},					//v1	- proton 90 at the end of first inept
		 ph2[2]  = {0,2},					//v2	- X 90 at the end of first inept
		 ph3[8]  = {0,0,0,0,2,2,2,2},				//v3	- proton 90 in 2nd inept
		 ph4[16] = {0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2},		//v4	- X 90 in 2nd inept
		 ph5[16] = {1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1};		//oph
/*------------------------------------------
Phase tables for rtgHSQC-BIRD
---------------------------------------------*/
static int	ph11[8]  = {1,1,1,1,3,3,3,3},							//v1
		ph12[2]  = {0,2},							//v2
		ph13[16] = {0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2},				//v3
		ph14[32] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2},			//v4
		ph15[32] = {1,3,1,3,3,1,3,1,3,1,3,1,1,3,1,3,3,1,3,1,1,3,1,3,1,3,1,3,3,1,3,1};			//oph			  			  
static int	ph17[4]  = {0,0,1,1},						//v7 - 1st 90 of bird and the hard 180
		ph18[4]  = {1,1,2,2},					//v8 - simpulse 180 of bird
		ph19[4]  = {2,2,3,3};					//v9 - 2nd 90 of bird 

/*--------------------- Phase table optionsl for rtgHSQC-BIRD via "kpph" ----------------------*/
//kpph = xy 	{nt=2/4/8/16/32} number of steps from phase cycle; if positive then use ph21-29 else ph31-39

//phase cycle on BIRD with kpph>0 		
static int	ph21[32] = {1,1,1,1,3,3,3,3,1,1,1,1,3,3,3,3,1,1,1,1,3,3,3,3,1,1,1,1,3,3,3,3},		//v1
		ph22[32] = {0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2},		//v2
		ph23[32] = {0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2},		//v3
		ph24[32] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2},		//v4
		ph25[32] = {1,3,1,3,3,1,3,1,3,1,3,1,1,3,1,3,3,1,3,1,1,3,1,3,1,3,1,3,3,1,3,1};		//oph			  			  
static int	ph27[32] = {0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1},		//v7 - 1st 90 of bird and the hard 180
		ph28[32] = {1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2},		//v8 - simpulse 180 of bird
		ph29[32] = {2,2,3,3,2,2,3,3,2,2,3,3,2,2,3,3,2,2,3,3,2,2,3,3,2,2,3,3,2,2,3,3};		//v9 - 2nd 90 of bird 
//the additional phase cycle is the least important to do (good for BASHD); kpph<0 		
static int	ph31[32] = {1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3},		//v1
		ph32[32] = {0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2},		//v2
		ph33[32] = {0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2},		//v3
		ph34[32] = {0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2},		//v4
		ph35[32] = {1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1,1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1};		//oph			  			  
static int	ph37[32] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},		//v7 - 1st 90 of bird and the hard 180
		ph38[32] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2},		//v8 - simpulse 180 of bird
		ph39[32] = {2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3};		//v9 - 2nd 90 of bird 
		


//test phase cycles 		
/*static int	ph21[64] = {1,1,1,1, 3,3,3,3, 1,1,1,1, 3,3,3,3, 1,1,1,1, 3,3,3,3, 1,1,1,1, 3,3,3,3,  1,1,3,3, 1,1,3,3, 1,1,3,3, 1,1,3,3, 1,1,3,3, 1,1,3,3, 1,1,3,3, 1,1,3,3 },		//v1
		ph22[64] = {0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2,  0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2, 0,2,0,2 },		//v2
		ph23[64] = {0,0,0,0, 0,0,0,0, 2,2,2,2, 2,2,2,2, 0,0,0,0, 0,0,0,0, 2,2,2,2, 2,2,2,2,  0,0,0,0, 2,2,2,2, 0,0,0,0, 2,2,2,2, 0,0,0,0, 2,2,2,2, 0,0,0,0, 2,2,2,2 },		//v3
		ph24[64] = {0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0, 2,2,2,2, 2,2,2,2, 2,2,2,2, 2,2,2,2,  0,0,0,0, 0,0,0,0, 2,2,2,2, 2,2,2,2, 0,0,0,0, 0,0,0,0, 2,2,2,2, 2,2,2,2 },		//v4
		ph25[64] = {1,3,1,3, 3,1,3,1, 3,1,3,1, 1,3,1,3, 3,1,3,1, 1,3,1,3, 1,3,1,3, 3,1,3,1,  1,3,3,1, 3,1,1,3, 3,1,1,3, 1,3,3,1, 1,3,3,1, 3,1,1,3, 3,1,1,3, 1,3,3,1 };		//oph			  			  
static int	ph27[64] = {0,0,1,1, 0,0,1,1, 0,0,1,1, 0,0,1,1, 0,0,1,1, 0,0,1,1, 0,0,1,1, 0,0,1,1,  2,2,2,2, 2,2,2,2, 2,2,2,2, 2,2,2,2, 3,3,3,3, 3,3,3,3, 3,3,3,3, 3,3,3,3 },		//v7 - 1st 90 of bird and the hard 180
		ph28[64] = {1,1,2,2, 1,1,2,2, 1,1,2,2, 1,1,2,2, 1,1,2,2, 1,1,2,2, 1,1,2,2, 1,1,2,2,  3,3,3,3, 3,3,3,3, 3,3,3,3, 3,3,3,3, 0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0 },		//v8 - simpulse 180 of bird
		ph29[64] = {2,2,3,3, 2,2,3,3, 2,2,3,3, 2,2,3,3, 2,2,3,3, 2,2,3,3, 2,2,3,3, 2,2,3,3,  0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0, 1,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,1 };		//v9 - 2nd 90 of bird 

static int	ph31[64] = {1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3, 1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3, 1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3, 1,1,3,3,1,1,3,3,1,1,3,3,1,1,3,3 },		//v1
		ph32[64] = {0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2, 0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2, 0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2, 0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,2 },		//v2
		ph33[64] = {0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2, 0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2, 0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2, 0,0,0,0,2,2,2,2,0,0,0,0,2,2,2,2 },		//v3
		ph34[64] = {0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2, 0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2, 0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2, 0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2 },		//v4
		ph35[64] = {1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1, 1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1, 1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1, 1,3,3,1,3,1,1,3,3,1,1,3,1,3,3,1 };		//oph			  			  
static int	ph37[64] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2, 3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3 },		//v7 - 1st 90 of bird and the hard 180
		ph38[64] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2, 3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 },		//v8 - simpulse 180 of bird
		ph39[64] = {2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2, 3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1 };		//v9 - 2nd 90 of bird 
*/




/*--------------------- Phase table options for rtgHSQC-BIRD via "kpph" ----------------------*/


pulsesequence()
{
/*-------------------------------------------------------
 DECLARE AND LOAD VARIABLES 
----------------------------------------------------------*/
//HSQC part

double  evolcorr=2.0*pw+4.0e-6,	
	tau = 1.0/(4.0*(getval("j1xh"))),	
	taug=2.0*tau,
	mult = getval("mult");

int	phase1 = (int)(getval("phase")+0.5),
	ZZgsign=1.0, 
	icosel;
//BIRD
double	d1_corr=0.0, j1xh = getval("j1xh"), j1yh = getval("j1yh"),
	rof3=getval("rof3"), 		//delay for receiver off - can be zero if ddrpm='r'
	tauA=getval("tauA"),		//compensation for tauB and tauC
	tauB=getval("tauB"),		//effect of rof2
	tauC=getval("tauC"),		//effect of alfa
	tBal=getval("tBal"),		//supports inova console if ~1/(fb*1.3)

	pw_HBIP = getval("pw_HBIP"),
	pw_XBIP = getval("pw_XBIP"), 
	pw_YBIP = getval("pw_YBIP"), 
	pwr_HBIP = getval("pwr_HBIP"),	
	pwr_XBIP = getval("pwr_XBIP"), 	
	pwr_YBIP = getval("pwr_YBIP"),
	
	pw_NH = getval("pw_NH"),
	pwr_NH = getval("pwr_NH"),	
	selfrq = getval("selfrq"), 	//exact transmitter frequency for NH-selective inversion used only if not equal to tof

	offRes_DEC = getval("offRes_DEC"), 	//not used if zero; set real dof for HPWR DEC
	offRes_X180 = getval("offRes_X180"), 	//not used if zero; set real dof for interchunk pulses
	
	calH = getval("calH"), 		//calibrate pw90
	calX = getval("calX"), 
	cal_pwlvl = getval("cal_pwlvl"), 
	cal_pwxlvl = getval("cal_pwxlvl"), 
	cal_pw = getval("cal_pw"), 	//if cal_pwlvl!=tpwr then use this with calH
	cal_pwx = getval("cal_pwx"), 	//if cal_pwxlvl!=pwxlvl then use this with calX


	gt1 = getval("gt1"),		//CTP during ACQ for BIRD or NHsel
	gzlvl1 = getval("gzlvl1"), 	
	gt2 = getval("gt2"),		//CTP during ACQ for hard 180
	gzlvl2 = getval("gzlvl2"), 	
	gstab = getval("gstab"),
	
	npoints=getval("npoints"),	// npoints should be an integer multiple of np
	cycles=np/npoints;
	/*********************/
		cycles = (double)((int)((cycles)));
		initval(cycles,v20);
	/*********************/
int 	kpph = (int)(getval("kpph")), 	//number of steps from the phase cycle to use
 	kp_X180 = (int)(getval("kp_X180")); 	
/*flag to change X pulses in BIRD 
  0: std. as before; 
  1: 2nd X-180 centred on the middle of the last proton 90 pulse; (BAD) 
  2: 2nd X-180 centred on the hard proton 180; (just an option, no reason to use and test)  
  3: kp method: there is a delay(pwx180) before BIRD and the 2nd X-180 is right after the BIRD (works properly with BIRDmode='b' on proteins)
  4: RA method: centred the 2nd X-180 to end simultanously with the last proton 90 in BIRD 

*/

	
char   	shp_HBIP[MAXSTR], shp_XBIP[MAXSTR], shp_NH[MAXSTR],
	lkgate_flg[MAXSTR], 
	homo[MAXSTR],
	hsgradaxis[MAXSTR],	//gradient axis for homospoil
	gradaxis[MAXSTR];	//gradient axis during ACQ ("t" implement simultanous XY)

	getstr("shp_HBIP",shp_HBIP);
	getstr("shp_XBIP",shp_XBIP);
	getstr("shp_NH",shp_NH);
        getstr("lkgate_flg",lkgate_flg);
	getstr("homo",homo);
        getstr("hsgradaxis",hsgradaxis);		
        getstr("gradaxis",gradaxis);	

//extensions for AD
double	pwx180 = getval("pwx180"),
	pwxlvl180 = getval("pwxlvl180"),
	pwx180r = getval("pwx180r"),
	pwxlvl180r = getval("pwxlvl180r");

char	pwx180ad[MAXSTR],
	pwx180adR[MAXSTR];
	getstr("pwx180ad", pwx180ad);
  	getstr("pwx180adR", pwx180adR);
//gradients
double 	gtE = getval("gtE"),		//HSQC encoding
	gzlvlE = getval("gzlvlE"),
	gtD = getval("gtD"),		//HSQC decoding
	gzlvlD = getval("gzlvlD"),

	hsglvl = getval("hsglvl"),
        hsgt = getval("hsgt"),
        hsgstab = getval("hsgstab");	

char   	BIRD[MAXSTR],          	 // Flag to choose gHSQC/rtgHSQC-BIRD ('n'/'y')
	BIRDmode[MAXSTR]; 	//Flag to choose hard/bip/wurst2i ('h'/'b'/'w') 13C inversion pulse within BIRD and NHselective refocusing via 'n'

	getstr("BIRD",BIRD);
	getstr("BIRDmode",BIRDmode);

char    sspul[MAXSTR], nullflg[MAXSTR], PFGflg[MAXSTR];

  	getstr("sspul",sspul);
	getstr("nullflg",nullflg);
  	getstr("PFGflg",PFGflg);

	
	if (kpph>32)
	{
	abort_message("kpph is too long...\n");
	}



//d1 correction was normalized to BIRDmode='b' and only supports HSQC/bip-BIRD/NHsel
	
	if (BIRD[0]=='n') d1_corr=(np/npoints)*(pw*4.0+1.0/j1xh+pw_XBIP+tauA+tauB+tauC+2.0*(gt1+gt2+2.0*gstab)+8.0*rof1);
	//if ((BIRD[0]=='n') && (BIRDmode[0]=='b')) d1_corr=(np/npoints)*(pw*4.0+1.0/j1xh+pw_XBIP+tauA+tauB+tauC+2.0*(gt1+gt2+2.0*gstab)+8.0*rof1);
	//if ((BIRD[0]=='n') && (BIRDmode[0]=='n')) d1_corr=(np/npoints)*(pw_NH+2.0*tauA+(pw*2.0+tauA+tauB+tauC)+2.0*(gt1+gt2+2.0*gstab)+4.0*rof1);	
	
	if ((BIRD[0]=='y') && (BIRDmode[0]=='n')) d1_corr=(np/npoints)*(4.0*rof1+(pw*4.0+1.0/j1xh+pw_XBIP+tauA+tauB+tauC+2.0*(gt1+gt2+2.0*gstab))-(pw_NH+2.0*tauA+(pw*2.0+tauA+tauB+tauC)+2.0*(gt1+gt2+2.0*gstab)));	
	if ((BIRD[0]=='y') && (BIRDmode[0]=='b')) d1_corr=0.0;
	
	
	if (d1_corr > 0.2*d1)
	{
	abort_message("Correction for relaxation delay is more than 20 percent! Check ACQ parameters...\n");
	}


	
//evolcorr and mult declarations
	evolcorr = 2*pw+4.0e-6;
	  
	if (mult > 0.5)
   	taug = 2*tau;
   	else
    	taug = gtE + gstab + 2*GRADIENT_DELAY;
   	ZZgsign=-1;
   	if (mult == 2) ZZgsign=1;
   	icosel = 1;

//setup the phase cycle
  	assign(ct,v10);


if (BIRD[0]=='n')
{
//gHSQC phases
	settable(t1,4,ph1);
	settable(t2,2,ph2);
	settable(t3,8,ph3);
	settable(t4,16,ph4);
	settable(t5,16,ph5);
}
else
{
//rtgHSQC-BIRD phases
    if (kpph==0) 
    {
	settable(t1,8,ph11);
	settable(t2,2,ph12);
	settable(t3,16,ph13);
	settable(t4,32,ph14);
	settable(t5,32,ph15);
	settable(t7,4,ph17);
	settable(t8,4,ph18);
	settable(t9,4,ph19);
    }
//implement phase cycle on BIRD and use only kpph step from the full cycle
    if (kpph>0) 
    {
	settable(t1,kpph,ph21);
	settable(t2,kpph,ph22);
	settable(t3,kpph,ph23);
	settable(t4,kpph,ph24);
	settable(t5,kpph,ph25);
	settable(t7,kpph,ph27);
	settable(t8,kpph,ph28);
	settable(t9,kpph,ph29);
    }
//do not implement phase cycle on BIRD and use only kpph step from the full cycle
    if (kpph<0) 
    {
	settable(t1,-kpph,ph31);
	settable(t2,-kpph,ph32);
	settable(t3,-kpph,ph33);
	settable(t4,-kpph,ph34);
	settable(t5,-kpph,ph35);
	settable(t7,-kpph,ph37);
	settable(t8,-kpph,ph38);
	settable(t9,-kpph,ph39);
    }
	
	getelem(t7, v10, v7);
  	getelem(t8, v10, v8);
	getelem(t9, v10, v9);
}

  	getelem(t1, v10, v1);		
  	getelem(t2, v10, v2);
  	getelem(t3, v10, v3);
  	getelem(t4, v10, v4);
	getelem(t5, v10, oph);
  	

   	initval(2.0*(double)(((int)(d2*getval("sw1")+0.5)%2)),v5);
   	if ((phase1 == 2) || (phase1 == 5))
     	icosel = -1;

   	add(v2,v5,v2);	
   	add(oph,v5,oph);

/* BEGIN PULSE SEQUENCE */
status(A);

//correct the total experiment time for HSQC-ref experiment  
	if ((d1_corr>0.0) && (BIRD[0]=='n')) delay(d1_corr);
	if ((d1_corr>0.0) && (BIRD[0]=='y') && (BIRDmode[0]=='n')) delay(d1_corr);

	if (sspul[A] == 'y')
	{
//lock gating
if (lkgate_flg[0] == 'y')  lk_hold(); /* turn lock sampling off */		
  
      if (PFGflg[A] == 'y')
      {
	obspower(tpwr);
	
	delay(5.0e-5);
	if (hsgt>0.0)
	{
	  if (hsgradaxis[0]=='t')  
	  { 
	    rgradient('x',hsglvl);
	    rgradient('y',hsglvl); 
	    delay(hsgt); 
	    rgradient('x',0.0); 
	    rgradient('y',0.0); 
	  }   
	  else 
	  {
	    if ((hsgradaxis[0]=='x') || (hsgradaxis[0]=='y')) 
	    { 
	    rgradient(hsgradaxis[0],hsglvl); 
	    delay(hsgt); 
	    rgradient(hsgradaxis[0],0.0); 
	    } 
	    else zgradpulse(hsglvl,hsgt); 
	  }
	}
        rgpulse(pw,zero,rof1,rof1);
	if (hsgt>0.0)
	{
	  if (hsgradaxis[0]=='t')  
	  { 
	    rgradient('x',hsglvl);
	    rgradient('y',hsglvl); 
	    delay(hsgt); 
	    rgradient('x',0.0); 
	    rgradient('y',0.0); 
	  }   
	  else 
	  {
	    if ((hsgradaxis[0]=='x') || (hsgradaxis[0]=='y')) 
	    { 
	    rgradient(hsgradaxis[0],hsglvl); 
	    delay(hsgt); 
	    rgradient(hsgradaxis[0],0.0); 
	    } 
	    else zgradpulse(hsglvl,hsgt); 
	  }
	}

      }
       	else
       	{
        obspower(tpwr-12);
	delay(5.0e-5);
        rgpulse(500*pw,zero,rof1,rof1);
        rgpulse(500*pw,one,rof1,rof1);
	}
	}

	if (nullflg[0]=='y') obspower(tpwr);
	else obspower(cal_pwlvl);
	decpower(pwxlvl);
	txphase(zero);
        decphase(zero);
	obsoffset(tof);
	decoffset(dof);
	
if (lkgate_flg[0] == 'y')  lk_sample(); /* turn lock sampling on */	
	delay(d1);
if (lkgate_flg[0] == 'y')  lk_hold(); /* turn lock sampling off */		
	delay(5.0e-5);

status(B);  

/****** null flag starts here *****/

      if (getflag("nullflg"))
      {
        rgpulse(0.5*pw,zero,rof1,rof1);
	txphase(zero);
	delay(2.0*tau);
	simpulse(2.0*pw,2.0*pwx,zero,zero,rof1,rof1); 
	txphase(two);
        delay(2.0*tau);
        rgpulse(1.5*pw,two,rof1,rof1);
	txphase(zero);
	
/* purgeing gradient */	
	if (hsgt>0.0)
	{
	  if (hsgradaxis[0]=='t')  
	  { 
	    rgradient('x',hsglvl);
	    rgradient('y',hsglvl); 
	    delay(hsgt); 
	    rgradient('x',0.0); 
	    rgradient('y',0.0); 
	  }   
	  else 
	  {
	    if ((hsgradaxis[0]=='x') || (hsgradaxis[0]=='y')) 
	    { 
	    rgradient(hsgradaxis[0],hsglvl); 
	    delay(hsgt); 
	    rgradient(hsgradaxis[0],0.0); 
	    } 
	    else zgradpulse(hsglvl,hsgt); 
	  }
	}
	if (cal_pwlvl!=tpwr) obspower(cal_pwlvl);
	delay(hsgstab);
      }

/****************************gHSQC or gHSQC part of pure shift starts here *************************/

//option to proton calibrations	  

	rgpulse(cal_pw*calH,zero,rof1,rof1); 	
	if (cal_pwlvl!=tpwr) obspower(tpwr);
	delay(tau);
	simpulse(2.0*pw,2.0*pwx,zero,zero,rof1,rof1); 
	txphase(v1);
	delay(tau);
     	rgpulse(pw,v1,rof1,rof1);
	
/* purgeing gradient */	
	if (hsgt>0.0)
	{
	  if (hsgradaxis[0]=='t')  
	  { 
	    rgradient('x',hsglvl);
	    rgradient('y',hsglvl); 
	    delay(2.0*hsgt); 
	    rgradient('x',0.0); 
	    rgradient('y',0.0); 
	  }   
	  else 
	  {
	    if ((hsgradaxis[0]=='x') || (hsgradaxis[0]=='y')) 
	    { 
	    rgradient(hsgradaxis[0],hsglvl); 
	    delay(2.0*hsgt); 
	    rgradient(hsgradaxis[0],0.0); 
	    } 
	    else zgradpulse(hsglvl,2.0*hsgt); 
	  }
	}
   	decphase(v2);
	if (cal_pwxlvl!=pwxlvl) decpower(cal_pwxlvl);
	delay(hsgstab);
//option to pwx calibrations	
	decrgpulse(cal_pwx*calX, v2, rof1, 2.0e-6); 
	txphase(zero);
	decphase(zero);
	if (cal_pwxlvl!=pwxlvl) decpower(pwxlvl);

	delay(d2/2.0);				// First half of t1 evolution
	rgpulse(2.0*pw,zero,2.0e-6,2.0e-6);
	delay(d2/2.0);				// Second half of t1 evolution

     	zgradpulse(gzlvlE,gtE);
	delay(taug - gtE - 2.0*GRADIENT_DELAY);
	simpulse(mult*pw,2.0*pwx,zero,zero,rof1,rof1);
	delay(taug + evolcorr); 

	decrgpulse(pwx,v4,2.0e-6,rof1);
	
/* purgeing gradient */	
	if (hsgt>0.0)
	{
	  if (hsgradaxis[0]=='t')  
	  { 
	    rgradient('x',ZZgsign*0.6*hsglvl);
	    rgradient('y',ZZgsign*0.6*hsglvl); 
	    delay(1.2*hsgt); 
	    rgradient('x',0.0); 
	    rgradient('y',0.0); 
	  }   
	  else 
	  {
	    if ((hsgradaxis[0]=='x') || (hsgradaxis[0]=='y')) 
	    { 
	    rgradient(hsgradaxis[0],ZZgsign*0.6*hsglvl); 
	    delay(1.2*hsgt); 
	    rgradient(hsgradaxis[0],0.0); 
	    } 
	    else zgradpulse(ZZgsign*0.6*hsglvl,1.2*hsgt); 
	  }
	}
	txphase(v3);
	delay(hsgstab);
/**/	
     	rgpulse(pw,v3,rof1,rof1);
	delay(tau - (2.0*pw/PI) - 2.0*rof1);
	simpulse(2.0*pw,2.0*pwx,zero,zero,rof1,rof1); 

	zgradpulse(icosel*gzlvlD,gtD);
	decpower(dpwr);	

	if (offRes_DEC!=0.0) decoffset(dof+offRes_DEC);

	delay(tau - gtD - 2.0*GRADIENT_DELAY - POWER_DELAY);

/********************************gHSQC part stops and BIRD Acquisition starts here**************************/

	delay(tBal);
	//filter delay (Hoult) for inova; adjust tBal manually for the same effect
	//delay(1.0/(getval("fb")*1.3))
							
//if (BIRD[0]=='y')
//{
setacqmode(WACQ|NZ);	//use this line only for vnmrs console; comment this out in inova


	obsblank();	
	delay(rof2);
	startacq(alfa);
//}
/*------------------------------------------------------------------------------------------------------------------------------
		Observe the 1st half chunk
--------------------------------------------------------------------------------------------------------------------------------*/
if (BIRD[0]=='y') 
{
status(C);	
	acquire(npoints/2.0,1.0/sw);
	rcvroff();					 	
status(B);
	obspower(tpwr);	
	txphase(v7);

/*change offset*/
	if (( (offRes_X180!=0.0) || (offRes_DEC!=0.0)) && (offRes_X180!=offRes_DEC)) decoffset(dof+offRes_X180);
	
/* optional CTP gradient */	
	if (gt1>0.0)
	{
	  
    if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl1);
      rgradient('y',gzlvl1); 
      delay(gt1); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {    
    if ((gradaxis[0]=='x') || (gradaxis[0]=='y')) 
    { 
      rgradient(gradaxis[0],gzlvl1); 
      delay(gt1); 
      rgradient(gradaxis[0],0.0); 
    } 
    else zgradpulse(gzlvl1,gt1); }
    
	delay(gstab);
	}
/**/	

	
/*------------------------------------------------------------------------						
Using hard 13C inversion pulse in BIRD
--------------------------------------------------------------------------*/
if (BIRDmode[0]== 'h')
{

  	if (kp_X180==3) { delay(2.0*pwx+2.0*rof1); } 
  
	rgpulse(pw,v7,rof1,rof1);		
	decpower(pwxlvl);		
	delay(2.0*tau);						
	simpulse(2.0*pw,2.0*pwx,v8,v8,rof1,rof1);
	//decpower(dpwr);	
	if (kp_X180==4) 
	{
	  parallelstart("obs");
	  delay(2.0*tau);
	  rgpulse(pw,v9,rof1,rof1);
	  parallelstart("dec");
	  parallelsync();
	  decrgpulse(2.0*pwx,v8,rof1,rof1);
	  parallelend();
	}
	else
	{
	  delay(2.0*tau);
	  if (kp_X180==1) { simpulse(pw,2.0*pwx,v9,v8,rof1,rof1); } 
	  else	rgpulse(pw,v9,rof1,rof1);
	  if (kp_X180==3) { decrgpulse(2.0*pwx,v8,rof1,rof1); } 
	}	

}

/*---------------------------------------------------------------------------
Using BIP 13C inversion pulse in BIRD
----------------------------------------------------------------------------*/
if (BIRDmode[0]== 'b')
{

  	if (kp_X180==3) { delay(pw_XBIP+2.0*rof1); } 
  
	rgpulse(pw,v7,rof1,rof1);		
	if (pwr_HBIP!=tpwr)  obspower(pwr_HBIP);
	if (pwr_XBIP!=pwxlvl) decpower(pwr_XBIP); else decpower(pwxlvl);		
	delay(2.0*tau);						
	simshaped_pulse(shp_HBIP,shp_XBIP,pw_HBIP,pw_XBIP,v8,v8,rof1,rof1);
	if (pwr_HBIP!=tpwr) obspower(tpwr);    
	//decpower(dpwr);	
	if (kp_X180==4) 
	{
	  parallelstart("obs");
	  delay(2.0*tau);
	  rgpulse(pw,v9,rof1,rof1);
	  parallelstart("dec");
	  parallelsync();
	  decshaped_pulse(shp_XBIP,pw_XBIP,v8,rof1,rof1);
	  parallelend();
	}
	else
	{
	  delay(2.0*tau);
	  if (kp_X180==1) { simshaped_pulse("",shp_XBIP,pw,pw_XBIP,v9,v8,rof1,rof1); } 
	  else	rgpulse(pw,v9,rof1,rof1);
	  if (kp_X180==3) { decshaped_pulse(shp_XBIP,pw_XBIP,v8,rof1,rof1); } 
	}	
	
}

/*--------------------------------------------------------------------------
Using a pair of wurst2i adiabatic 13C inversion pulses in BIRD
----------------------------------------------------------------------------*/
if (BIRDmode[0]== 'w')
{
	rgpulse(pw,v7,rof1,rof1);				
	if (pwr_HBIP!=tpwr)  obspower(pwr_HBIP);
	if (pwxlvl180!=pwxlvl) decpower(pwxlvl180); else decpower(pwxlvl);		
	txphase(v8); decphase(v8);
	delay(2.0*tau);						
      	decshaped_pulse(pwx180ad, pwx180, v8, rof1, rof1);
     	shaped_pulse(shp_HBIP,pw_HBIP,v8,rof1,rof1);
	if (pwr_HBIP!=tpwr) obspower(tpwr);    			
	txphase(v9); 
	delay(2.0*tau);		
      	decshaped_pulse(pwx180adR, pwx180, v8, rof1, rof1);
	//decpower(dpwr);
	if (kp_X180==1) { simpulse(pw,2.0*pwx,v9,v8,rof1,rof1); } 
	else	rgpulse(pw,v9,rof1,rof1);

}

/*---------------------------------------------------------------------------
NHselective option for proteins
----------------------------------------------------------------------------*/
if (BIRDmode[0]== 'n')
{

	if (pwr_NH!=tpwr)  obspower(pwr_NH);
	if (selfrq!=tof) obsoffset(selfrq);
	delay(tauA);						
	shaped_pulse(shp_NH,pw_NH,v7,rof1,rof1);
	if (pwr_NH!=tpwr) obspower(tpwr);
	if (selfrq!=tof) obsoffset(tof);	
	delay(tauA);
	
}

/* optional CTP gradient */	
	if (gt1>0.0)
	{
	      if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl1);
      rgradient('y',gzlvl1); 
      delay(gt1); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {
	    if ((gradaxis[0]=='x') || (gradaxis[0]=='y')) 
    { 
      rgradient(gradaxis[0],gzlvl1); 
      delay(gt1); 
      rgradient(gradaxis[0],0.0); 
    } 
    else zgradpulse(gzlvl1,gt1); }
	delay(gstab);
	}
/**/	

/****************** hard180 ***************************/

	delay(tauA);
	
/* optional CTP gradient */	
	if (gt2>0.0)
	{
	      if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl2);
      rgradient('y',gzlvl2); 
      delay(gt2); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {
	    if ((gradaxis[1]=='x') || (gradaxis[1]=='y')) 
    { 
      rgradient(gradaxis[1],gzlvl2); 
      delay(gt2); 
      rgradient(gradaxis[1],0.0); 
    } 
    else zgradpulse(gzlvl2,gt2); }
	delay(gstab);
	}

 /************ hard 180 degree refocusing pulse *********/
	if (kp_X180==2) 
	{ 
	if (BIRDmode[0]== 'h') { simpulse(2.0*pw,2.0*pwx,v7,v8,rof1,rof1); } 
	if (BIRDmode[0]== 'b') { simshaped_pulse("",shp_XBIP,2.0*pw,pw_XBIP,v7,v8,rof1,rof1); } 
	} 
	else	rgpulse(2.0*pw,v7,rof1,rof1);

	//rgpulse(pw*2.0,v7,rof1,rof1);   

	
/* optional CTP gradient */	
	if (gt2>0.0)
	{
	      if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl2);
      rgradient('y',gzlvl2); 
      delay(gt2); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {
	    if ((gradaxis[1]=='x') || (gradaxis[1]=='y')) 
    { 
      rgradient(gradaxis[1],gzlvl2); 
      delay(gt2); 
      rgradient(gradaxis[1],0.0); 
    } 
    else zgradpulse(gzlvl2,gt2); }
	delay(gstab);
	}

/*change offset*/
	if (( (offRes_X180!=0.0) || (offRes_DEC!=0.0)) && (offRes_X180!=offRes_DEC)) decoffset(dof+offRes_DEC);


/*change DEC power*/	
	decpower(dpwr);	

	obsblank();
	delay(tauB);
	rcvron(); 	//this includes rof3
	delay(tauC);

decr(v20);	

/*------------------------------------------------------------------------------------------------------------------------------
		Loops for more chunks
--------------------------------------------------------------------------------------------------------------------------------*/

starthardloop(v20);
status(C);	
	acquire(npoints,1.0/sw);	
	rcvroff();					 

status(B);
	obspower(tpwr);						
	txphase(v7);

/*change offset*/
	if (( (offRes_X180!=0.0) || (offRes_DEC!=0.0)) && (offRes_X180!=offRes_DEC)) decoffset(dof+offRes_X180);

/* optional CTP gradient */	
	if (gt1>0.0)
	{
	  
    if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl1);
      rgradient('y',gzlvl1); 
      delay(gt1); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {    
    if ((gradaxis[0]=='x') || (gradaxis[0]=='y')) 
    { 
      rgradient(gradaxis[0],gzlvl1); 
      delay(gt1); 
      rgradient(gradaxis[0],0.0); 
    } 
    else zgradpulse(gzlvl1,gt1); }
    
	delay(gstab);
	}
/**/	

	
/*------------------------------------------------------------------------						
Using hard 13C inversion pulse in BIRD
--------------------------------------------------------------------------*/
if (BIRDmode[0]== 'h')
{

  	if (kp_X180==3) { delay(2.0*pwx+2.0*rof1); } 
  
	rgpulse(pw,v7,rof1,rof1);		
	decpower(pwxlvl);		
	delay(2.0*tau);						
	simpulse(2.0*pw,2.0*pwx,v8,v8,rof1,rof1);
	//decpower(dpwr);	
	if (kp_X180==4) 
	{
	  parallelstart("obs");
	  delay(2.0*tau);
	  rgpulse(pw,v9,rof1,rof1);
	  parallelstart("dec");
	  parallelsync();
	  decrgpulse(2.0*pwx,v8,rof1,rof1);
	  parallelend();
	}
	else
	{
	  delay(2.0*tau);
	  if (kp_X180==1) { simpulse(pw,2.0*pwx,v9,v8,rof1,rof1); } 
	  else	rgpulse(pw,v9,rof1,rof1);
	  if (kp_X180==3) { decrgpulse(2.0*pwx,v8,rof1,rof1); } 
	}	

}

/*---------------------------------------------------------------------------
Using BIP 13C inversion pulse in BIRD
----------------------------------------------------------------------------*/
if (BIRDmode[0]== 'b')
{

  	if (kp_X180==3) { delay(pw_XBIP+2.0*rof1); } 
  
	rgpulse(pw,v7,rof1,rof1);		
	if (pwr_HBIP!=tpwr)  obspower(pwr_HBIP);
	if (pwr_XBIP!=pwxlvl) decpower(pwr_XBIP); else decpower(pwxlvl);		
	delay(2.0*tau);						
	simshaped_pulse(shp_HBIP,shp_XBIP,pw_HBIP,pw_XBIP,v8,v8,rof1,rof1);
	if (pwr_HBIP!=tpwr) obspower(tpwr);    
	//decpower(dpwr);	
	if (kp_X180==4) 
	{
	  parallelstart("obs");
	  delay(2.0*tau);
	  rgpulse(pw,v9,rof1,rof1);
	  parallelstart("dec");
	  parallelsync();
	  decshaped_pulse(shp_XBIP,pw_XBIP,v8,rof1,rof1);
	  parallelend();
	}
	else
	{
	  delay(2.0*tau);
	  if (kp_X180==1) { simshaped_pulse("",shp_XBIP,pw,pw_XBIP,v9,v8,rof1,rof1); } 
	  else	rgpulse(pw,v9,rof1,rof1);
	  if (kp_X180==3) { decshaped_pulse(shp_XBIP,pw_XBIP,v8,rof1,rof1); } 
	}	
	
}

/*--------------------------------------------------------------------------
Using a pair of wurst2i adiabatic 13C inversion pulses in BIRD
----------------------------------------------------------------------------*/
if (BIRDmode[0]== 'w')
{
	rgpulse(pw,v7,rof1,rof1);				
	if (pwr_HBIP!=tpwr)  obspower(pwr_HBIP);
	if (pwxlvl180!=pwxlvl) decpower(pwxlvl180); else decpower(pwxlvl);		
	txphase(v8); decphase(v8);
	delay(2.0*tau);						
      	decshaped_pulse(pwx180ad, pwx180, v8, rof1, rof1);
     	shaped_pulse(shp_HBIP,pw_HBIP,v8,rof1,rof1);
	if (pwr_HBIP!=tpwr) obspower(tpwr);    			
	txphase(v9); 
	delay(2.0*tau);		
      	decshaped_pulse(pwx180adR, pwx180, v8, rof1, rof1);
	//decpower(dpwr);
	rgpulse(pw,v9,rof1,rof1);

}

/*---------------------------------------------------------------------------
NHselective option for proteins
----------------------------------------------------------------------------*/
if (BIRDmode[0]== 'n')
{

	if (pwr_NH!=tpwr)  obspower(pwr_NH);
	if (selfrq!=tof) obsoffset(selfrq);
	delay(tauA);						
	shaped_pulse(shp_NH,pw_NH,v7,rof1,rof1);
	if (pwr_NH!=tpwr) obspower(tpwr);
	if (selfrq!=tof) obsoffset(tof);	
	delay(tauA);
	
}

/* optional CTP gradient */	
	if (gt1>0.0)
	{
	      if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl1);
      rgradient('y',gzlvl1); 
      delay(gt1); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {
	    if ((gradaxis[0]=='x') || (gradaxis[0]=='y')) 
    { 
      rgradient(gradaxis[0],gzlvl1); 
      delay(gt1); 
      rgradient(gradaxis[0],0.0); 
    } 
    else zgradpulse(gzlvl1,gt1); }
	delay(gstab);
	}
/**/	

/****************** hard180 ***************************/

	delay(tauA);
	
/* optional CTP gradient */	
	if (gt2>0.0)
	{
	      if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl2);
      rgradient('y',gzlvl2); 
      delay(gt2); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {
	    if ((gradaxis[1]=='x') || (gradaxis[1]=='y')) 
    { 
      rgradient(gradaxis[1],gzlvl2); 
      delay(gt2); 
      rgradient(gradaxis[1],0.0); 
    } 
    else zgradpulse(gzlvl2,gt2); }
	delay(gstab);
	}

 /************ hard 180 degree refocusing pulse *********/
	if (kp_X180==2) 
	{ 
	if (BIRDmode[0]== 'h') { simpulse(2.0*pw,2.0*pwx,v7,v8,rof1,rof1); } 
	if (BIRDmode[0]== 'b') { simshaped_pulse("",shp_XBIP,2.0*pw,pw_XBIP,v7,v8,rof1,rof1); } 
	} 
	else	rgpulse(2.0*pw,v7,rof1,rof1);

	//rgpulse(pw*2.0,v7,rof1,rof1);   

	
/* optional CTP gradient */	
	if (gt2>0.0)
	{
	      if (gradaxis[0]=='t')  
    { 
      rgradient('x',gzlvl2);
      rgradient('y',gzlvl2); 
      delay(gt2); 
      rgradient('x',0.0); 
      rgradient('y',0.0); 
    }   
else {
	    if ((gradaxis[1]=='x') || (gradaxis[1]=='y')) 
    { 
      rgradient(gradaxis[1],gzlvl2); 
      delay(gt2); 
      rgradient(gradaxis[1],0.0); 
    } 
    else zgradpulse(gzlvl2,gt2); }
	delay(gstab);
	}

/*change offset*/
	if (( (offRes_X180!=0.0) || (offRes_DEC!=0.0)) && (offRes_X180!=offRes_DEC)) decoffset(dof+offRes_DEC);

/*change DEC power*/	
	decpower(dpwr);	

	obsblank();
	delay(tauB);
	rcvron(); 	//this includes rof3
	delay(tauC);
	


endhardloop(); 

/*------------------------------------------------------------------------------------------------------------------------------
		Acquisition of last half chunk
--------------------------------------------------------------------------------------------------------------------------------*/
status(C);	
	acquire(npoints/2.0,1.0/sw);
	rcvroff();					 	
	endacq();
	incr(v20);
	
	if (lkgate_flg[0] == 'y')  lk_sample(); /* turn lock sampling on */	
}

					/****** BIRD ends here for all *****/


/************************ ACQ for conventional gHSQC ***********************************/
						
else 
{
if (homo[A]=='y')
{   status(C);	
}
else  
{  
  status(C);	
	acquire(np,1.0/sw);
	rcvroff();					 	

	if (lkgate_flg[0] == 'y')  lk_sample(); /* turn lock sampling on */	
}	  
}

}
/********************** PULSE SEQUENCE ENDS HERE****************************************/
